==============================================================
``psyclone.domain.nemo.transformations.create_nemo_psy_trans``
==============================================================

.. automodule:: psyclone.domain.nemo.transformations.create_nemo_psy_trans

   .. contents::
      :local:

.. currentmodule:: psyclone.domain.nemo.transformations.create_nemo_psy_trans


Classes
=======

- :py:class:`CreateNemoPSyTrans`:
  Transform generic (language-level) PSyIR representation into a PSyclone


.. autoclass:: CreateNemoPSyTrans
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: CreateNemoPSyTrans
      :parts: 1
